@@ -145,8 +145,8 @@ construct_recipients (CryptUIKeyChooser *chooser, GtkBox *box)
     GtkWidget *hbox;
 
     /* Top filter box */
-    hbox = gtk_hbox_new (FALSE, 12);
-    
+    hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
+
     /* Filter Combo */
     chooser->priv->filtermode = GTK_COMBO_BOX (gtk_combo_box_text_new ());
     gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (chooser->priv->filtermode), _("All Keys"));
@@ -194,6 +194,7 @@ construct_recipients (CryptUIKeyChooser *chooser, GtkBox *box)
                                                     CRYPTUI_KEY_LIST_CHECKS);
     gtk_tree_view_set_enable_search (GTK_TREE_VIEW (chooser->priv->keylist), FALSE);
     scroll = gtk_scrolled_window_new (NULL, NULL);
+    gtk_widget_set_size_request (scroll, 500, 300);
     gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scroll), 
                                     GTK_POLICY_AUTOMATIC, GTK_POLICY_ALWAYS);
     gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scroll), GTK_SHADOW_IN);
@@ -251,8 +252,8 @@ construct_signer (CryptUIKeyChooser *chooser, GtkBox *box)
         g_list_free (keys);
     } else if (count > 1) {
         /* Top filter box */
-        hbox = gtk_hbox_new (FALSE, 12);
-        
+        hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
+
         /* Sign Label */
         label = gtk_label_new (_("_Sign message as:"));
         gtk_label_set_use_underline (GTK_LABEL (label), TRUE);
